'use strict';

var XPayUtils = require("~/../int_nexixpay/cartridge/scripts/util/XPayUtils");
var logger = dw.system.Logger.getLogger('nexi.xpay.bm');

/**
  * call a XPay API RESTful api to perform a subsequent recurring payment after a first payment
  * 
  * for params json specs see:
  * {@link https://ecommerce.nexi.it/specifiche-tecniche/pagamentoricorrente/pagamentisuccessivi.html}
  * 
  * @returns {Result} a json response
  */
function subseqPay(params) {
    
    params = params || {};
        
    //apiKey=<val>numeroContratto=<val>codiceTransazione=<val>importo=<val> divisa=<val>scadenza=<val>timeStamp=<val><chiaveSegreta>    
	params.mac = XPayUtils.sha1(
		'apiKey=' +params.apiKey + 
        'numeroContratto=' + params.numeroContratto + 
        'codiceTransazione=' + params.codiceTransazione + 
        'importo=' + params.importo + 
        'divisa=' + params.divisa + 
        'scadenza=' + params.scadenza + 
        'timeStamp=' + params.timeStamp + 
        XPayUtils.XPAY_TERM_RICO_SECRETKEY);
	
	//obtains a Service object by calling the LocalServiceRegistry.createService method. 
	//The method takes two arguments: the name of a service configuration, 
	//and a script object that contains callback code that you provide	 
	var recurPayWs = dw.svc.LocalServiceRegistry.createService("Nexi.XPay.restservice", {
        createRequest: function(svc: HTTPService, args) {
            svc.setRequestMethod("POST");
            if(args) {
                logger.debug('RecurPaySvc - request {0} :\n{1}', this.URL, JSON.stringify(args, null, '\t'));
            	svc.addHeader("Content-Type", "application/json");            	
            	return JSON.stringify(args);
            }            
        },
        parseResponse: function(svc: HTTPService, client: HTTPClient) {
            return client.text;
        },
        mockCall: function(svc: HTTPService, client: HTTPClient) {
            return {
                statusCode: 200,
                statusMessage: "Success",
                text: '{}'
            };
        }
    });
	recurPayWs.URL += "/ecomm/api/recurring/pagamentoRicorrente";
    
	var result : Result = recurPayWs.call(params);
	
	return result;
}


exports.subseqPay = subseqPay;