'use strict';

/* General Scripts */
var guard = require('*/cartridge/scripts/guard');
var ISML = require('dw/template/ISML');
var OrderMgr = require('dw/order/OrderMgr');

/* Logger */
var logger = dw.system.Logger.getLogger('nexi.xpay.bm');

/* XPay modules */
var XPayRecurPay = require("~/../int_nexixpay/cartridge/scripts/util/XPayRecurPay");

const MAX_QUERY_RESULTS = 100;

/**
 * Initialize the search transaction page
 * @returns
 */
function start(pdict){
	session.forms.bosearch.transactionid.value = '';    
	
	var topUrl = dw.web.URLUtils.url('SiteNavigationBar-ShowMenuitemOverview', 'CurrentMenuItemId', request.httpParameterMap.CurrentMenuItemId);
	if(!request.httpParameterMap.CurrentMenuItemId.value){
		topUrl = request.httpParameterMap.TopUrl.value;
	}
    var mainMenuName = request.httpParameterMap.mainmenuname.stringValue;
    session.forms.bosearch.bc_root_name.value = mainMenuName;
    session.forms.bosearch.bc_root_link.value = topUrl;
    
    session.custom.title = request.httpParameterMap.title.value;
    
	return renderSearch({
		topUrl: topUrl,
		mainMenuName: mainMenuName,
		title: session.custom.title.value
	});	
}


/**
 * Handles form actions (search and reimbursement actions)
 * @returns
 */
function handleForm() {
	
	session.forms.bosearch.transactionid.value = session.forms.bosearch.transactionid.value || '';
	
	var triggeredAction = request.triggeredFormAction;
	if (!empty(triggeredAction)) {
		if(triggeredAction.formId === 'search') {			
			return getTransactions();
		}
	}
	return start();
}

/**
 * Renders the XPayRecurTester template with all related args
 * @param args
 * @returns
 */
function renderSearch(args) {

	args = args || {};

    return ISML.renderTemplate('XPayRecurTester', {
        ContinueURL     : dw.web.URLUtils.https('XPayRecurTester-HandleForm'),
        CurrentForms    : session.forms,
        rows 	        : args.rows || [],
        TOP_URL         : args.topUrl,
        MAIN_MENU_NAME  : args.mainMenuName,
        errorMsg 		: args.errorMsg || '',
        infoMsg 		: args.infoMsg || '',
        from			: args.from,
        to				: args.to,
        title			: args.title,
    });
}


/**
 * Gets all the transactions controller's logic
 * @returns
 */
function getTransactions() {

	var args = {};
	args.errorMsg = '';
	args.transactionid = session.forms.bosearch.transactionid.value;
	args.status = ['Autorizzato'];//, 'Negato', 'Annullato'];
	args.period = (args.from && args.to) ? (args.from+' - '+ args.to) : '';
	args.channel = 'All';
	args.topUrl = session.forms.bosearch.bc_root_link.value;
    args.mainMenuName = session.forms.bosearch.bc_root_name.value;
    args.title = session.custom.title.value;
	args.rows = [];
	
	/*if(!args.transactionid){
		args.errorMsg = dw.web.Resource.msg('search.invalidFilters', 'backoffice', null);
		return renderSearch(args);
	}*/

	var iter = null;
	if(args.transactionid) {
		var query = '(custom.xpay_transactionCode LIKE {0} OR orderNo LIKE {0}) AND custom.xpay_transactionCode != null AND custom.xpay_recurContractNum != null';
		iter = OrderMgr.searchOrders(
			query, 
			'orderNo ASC', 
			args.transactionid);
	}
	else {
		var query = 'custom.xpay_transactionCode != null AND custom.xpay_recurContractNum != null';
		iter = OrderMgr.searchOrders(
			query, 
			'creationDate DESC', 
			'');
	}
			
	var numResults = 0;
	if(iter.getCount() > 0) {		
		while(iter.hasNext() && numResults < MAX_QUERY_RESULTS) {
            var order = iter.next();
            
			var rowItem = {
				alias : order.paymentTransaction.custom.xpay_alias,
				codiceTransazione: order.custom.xpay_transactionCode,
				importo: order.paymentTransaction.amount,
				divisa: 'EUR',
				dataTransazione: order.paymentTransaction.custom.xpay_data,
				xpay_recurContractNum: order.custom.xpay_recurContractNum || '-',
				orderNumber: order.orderNo,				
				orderToken: order.orderToken,
				orderStatus: order.status.displayValue,								
				tcontabLabel : order.paymentTransaction.custom.xpay_tcontab.displayValue,
				tcontabValue : order.paymentTransaction.custom.xpay_tcontab.value,
				actionLink: dw.web.URLUtils.url('XPayRecurTester-RecurPay',  
						'orderNum', order.orderNo,
						'TransactionId', order.custom.xpay_transactionCode,
						'TopUrl', session.forms.bosearch.bc_root_link.value,
						'MainMenuName', session.forms.bosearch.bc_root_name.value),			
                trxLink: dw.web.URLUtils.url('NexiPayTransactionMng-SelectTransaction',  
                        'TransactionId', order.custom.xpay_transactionCode,
                        'orderNum', order.orderNo,
						'TopUrl', session.forms.bosearch.bc_root_link.value,
						'MainMenuName', session.forms.bosearch.bc_root_name.value,
						//'mode', args.mode,
                        'alias', order.paymentTransaction.custom.xpay_alias)
            };
			args.rows.push(rowItem);
			numResults++;
		}
	}
	iter.close();
	
	return renderSearch(args);
}


function recurPay() {
    
    var args = {};
    args.errorMsg = '';
    args.infoMsg = '';
    args.topUrl = session.forms.bosearch.bc_root_link.value;
    args.mainMenuName = session.forms.bosearch.bc_root_name.value;
        
    try {
        var order = OrderMgr.getOrder(request.httpParameterMap.orderNum.value);            

        if(empty(order.custom.xpay_recurContractNum)) throw {            
            errorMessage : 'Missing recurring contract number'
        }
        
        var result = XPayRecurPay.execRecurPay(order);

        var jsonReq = result.jsonRequest;
        var jsonRes = result.jsonResponse;
        
        args.infoMsg += 'REQUEST:\n';
        args.infoMsg += JSON.stringify(jsonReq, null, '\t');
        args.infoMsg += '\n\n';
        args.infoMsg += 'RESPONSE:\n';
        args.infoMsg += JSON.stringify(jsonRes, null, '\t');
    } 
    catch(ex) {
        args.errorMsg = JSON.stringify(ex);
        logger.error('Exception: '+args.errorMsg);        
    }
    
    return renderSearch(args);
}


exports.Start      = guard.ensure(['https'], start);
exports.HandleForm = guard.ensure(['https', 'post'], handleForm);
exports.RecurPay   = guard.ensure(['https'], recurPay);